# - Config file for the IGNITION-RNDF package.
#
# For finding and loading IGNITION-RNDF from your project, type:
#
# find_package(ignition-rndf0)
#
# It defines the following variables:
#
#  ignition-rndf0_FOUND       - System has IGNITION-RNDF.
#  IGNITION-RNDF_INCLUDE_DIRS - include directories for IGNITION-RNDF and its dependencies.
#  IGNITION-RNDF_LIBRARY_DIRS - Paths in which the linker should search for libraries.
#  IGNITION-RNDF_LIBRARIES    - Libraries to link against.
#  IGNITION-RNDF_CXX_FLAGS    - Compiler flags for compiling C++ sources.
#  IGNITION-RNDF_LDFLAGS      - Linker flags.

include (FindPkgConfig REQUIRED)

if (IGNITION-RNDF_CONFIG_INCLUDED)
  return()
endif()
set(IGNITION-RNDF_CONFIG_INCLUDED TRUE)

list(APPEND IGNITION-RNDF_INCLUDE_DIRS
"/usr/include/ignition/rndf0")

list(APPEND IGNITION-RNDF_LIBRARY_DIRS
"/usr/lib/x86_64-linux-gnu")

# Visual Studio enables c++11 support by default
if (NOT MSVC)
  list(APPEND IGNITION-RNDF_CXX_FLAGS -std=c++11)
endif()
if (${CMAKE_CXX_COMPILER_ID} MATCHES "Clang")
  set(IGNITION-RNDF_CXX_FLAGS "${IGNITION-RNDF_CXX_FLAGS} -stdlib=libc++")
endif ()

# On Windows we need to link against .lib files with no prefix.
if (WIN32)
  SET(CMAKE_FIND_LIBRARY_PREFIXES "")
  SET(CMAKE_FIND_LIBRARY_SUFFIXES ".lib")
endif()

foreach(lib ignition-rndf0)
  set(onelib "${lib}-NOTFOUND")
  find_library(onelib ${lib}
    PATHS "/usr/lib/x86_64-linux-gnu"
    NO_DEFAULT_PATH
    )
  if(NOT onelib)
    message(FATAL_ERROR "Library '${lib}' in package IGNITION-RNDF is not installed properly")
  endif()
  list(APPEND IGNITION-RNDF_LIBRARIES ${onelib})
endforeach()

if (MSVC)
  list(APPEND IGNITION-RNDF_LIBRARIES Ws2_32.lib Iphlpapi.lib)
endif()

list(APPEND IGNITION-RNDF_LDFLAGS -L"/usr/lib/x86_64-linux-gnu")

#################################################
# Find ign math library
find_package(ignition-math2 2.4 QUIET)
if (NOT ignition-math2_FOUND)
  message(STATUS "Looking for ignition-math2-config.cmake - not found")
else()
  message(STATUS "Looking for ignition-math2 - found")
endif()
list(APPEND IGNITION-RNDF_INCLUDE_DIRS ${IGNITION-MATH_INCLUDE_DIRS})
list(APPEND IGNITION-RNDF_LIBRARY_DIRS ${IGNITION-MATH_LIBRARY_DIRS})
list(APPEND IGNITION-RNDF_LIBRARIES ${IGNITION-MATH_LIBRARIES})
